@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,17 +49,15 @@
 
 package com.openexchange.calendar;
 
-import com.openexchange.api2.OXException;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.calendar.CalendarDataObject;
 import com.openexchange.groupware.container.Appointment;
 import com.openexchange.tools.iterator.SearchIterator;
-import com.openexchange.tools.iterator.SearchIteratorException;
 
 /**
  * This is a delegating iterator for converting the {@link SearchIterator} specialized for {@link CalendarDataObject}s into a
  * {@link SearchIterator} for {@link Appointment}s. This delegating {@link SearchIterator} is necessary to seperate internal calendar
- * module iterators from external ones. 
+ * module iterators from external ones.
  *
  * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
  */
@@ -75,7 +73,7 @@ public final class AppointmentIteratorAdapter implements SearchIterator<Appointm
         delegate.addWarning(warning);
     }
 
-    public void close() throws SearchIteratorException {
+    public void close() throws AbstractOXException {
         delegate.close();
     }
 
@@ -83,23 +81,19 @@ public final class AppointmentIteratorAdapter implements SearchIterator<Appointm
         return delegate.getWarnings();
     }
 
-    public boolean hasNext() {
+    public boolean hasNext() throws AbstractOXException{
         return delegate.hasNext();
     }
 
-    public boolean hasSize() {
-        return delegate.hasSize();
-    }
-
     public boolean hasWarnings() {
         return delegate.hasWarnings();
     }
 
-    public Appointment next() throws SearchIteratorException, OXException {
+    public Appointment next() throws AbstractOXException {
         return delegate.next();
     }
 
     public int size() {
         return delegate.size();
     }
-}
\ No newline at end of file
+}
