@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -65,6 +65,7 @@ import com.openexchange.calendar.storage.ParticipantStorage;
 import com.openexchange.configuration.ServerConfig;
 import com.openexchange.configuration.ServerConfig.Property;
 import com.openexchange.database.DBPoolingException;
+import com.openexchange.database.provider.SimpleDBProvider;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.Types;
 import com.openexchange.groupware.attach.AttachmentBase;
@@ -72,15 +73,14 @@ import com.openexchange.groupware.attach.AttachmentException;
 import com.openexchange.groupware.attach.Attachments;
 import com.openexchange.groupware.calendar.CalendarConfig;
 import com.openexchange.groupware.calendar.CalendarDataObject;
+import com.openexchange.groupware.calendar.CalendarFolderObject;
 import com.openexchange.groupware.calendar.OXCalendarException;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.container.UserParticipant;
 import com.openexchange.groupware.contexts.Context;
-import com.openexchange.groupware.tx.SimpleDBProvider;
 import com.openexchange.server.impl.DBPool;
 import com.openexchange.tools.StringCollection;
 import com.openexchange.tools.iterator.SearchIterator;
-import com.openexchange.tools.iterator.SearchIteratorException;
 
 /**
  * CachedCalendarIterator
@@ -89,7 +89,7 @@ import com.openexchange.tools.iterator.SearchIteratorException;
 
 public class CachedCalendarIterator implements SearchIterator<CalendarDataObject> {
 
-    private static final Log LOG = LogFactory.getLog(CachedCalendarIterator.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(CachedCalendarIterator.class));
 
 	private final List<AbstractOXException> warnings;
     private final List<CalendarDataObject> list;
@@ -107,9 +107,12 @@ public class CachedCalendarIterator implements SearchIterator<CalendarDataObject
     public static int MAX_PRE_FETCH = 20;
     private int pre_fetch;
 
-    public CachedCalendarIterator(final SearchIterator<CalendarDataObject> non_cached_iterator, final Context c, final int uid) throws SearchIteratorException, OXException {
+    private CalendarFolderObject visibleFolders;
+
+    public CachedCalendarIterator(CalendarFolderObject visibleFolders, final SearchIterator<CalendarDataObject> non_cached_iterator, final Context c, final int uid) throws AbstractOXException {
     	this.warnings =  new ArrayList<AbstractOXException>(2);
     	list = new ArrayList<CalendarDataObject>(16);
+    	this.visibleFolders = visibleFolders;
         this.non_cached_iterator = non_cached_iterator;
         this.c = c;
         this.uid = uid;
@@ -121,7 +124,11 @@ public class CachedCalendarIterator implements SearchIterator<CalendarDataObject
         }
     }
 
-    public CachedCalendarIterator(final SearchIterator<CalendarDataObject> non_cached_iterator, final Context c, final int uid, final int[][] oids) throws SearchIteratorException, OXException {
+    public CachedCalendarIterator(final SearchIterator<CalendarDataObject> non_cached_iterator, final Context c, final int uid) throws AbstractOXException {
+        this(null, non_cached_iterator, c, uid);
+    }
+
+    public CachedCalendarIterator(final SearchIterator<CalendarDataObject> non_cached_iterator, final Context c, final int uid, final int[][] oids) throws AbstractOXException {
     	this.warnings =  new ArrayList<AbstractOXException>(2);
     	if (non_cached_iterator.hasWarnings()) {
     		warnings.addAll(Arrays.asList(non_cached_iterator.getWarnings()));
@@ -139,7 +146,7 @@ public class CachedCalendarIterator implements SearchIterator<CalendarDataObject
         }
     }
 
-    public boolean hasNext() {
+    public boolean hasNext() throws AbstractOXException {
         if (!cache) {
             return non_cached_iterator.hasNext();
         }
@@ -153,7 +160,7 @@ public class CachedCalendarIterator implements SearchIterator<CalendarDataObject
         return false;
     }
 
-    public CalendarDataObject next() throws SearchIteratorException, OXException {
+    public CalendarDataObject next() throws AbstractOXException {
         if (!oxonfe) {
             if (!cache) {
                 if (oids != null) {
@@ -177,7 +184,7 @@ public class CachedCalendarIterator implements SearchIterator<CalendarDataObject
         return null;
     }
 
-    public final void close() throws SearchIteratorException {
+    public final void close() throws AbstractOXException {
         if (closed) {
             return;
         }
@@ -189,10 +196,6 @@ public class CachedCalendarIterator implements SearchIterator<CalendarDataObject
         return non_cached_iterator.size();
     }
 
-    public boolean hasSize() {
-        return non_cached_iterator.hasSize();
-    }
-
     public void addWarning(final AbstractOXException warning) {
 		warnings.add(warning);
 	}
@@ -205,7 +208,7 @@ public class CachedCalendarIterator implements SearchIterator<CalendarDataObject
 		return !warnings.isEmpty();
 	}
 
-    private final void fillCachedResultSet() throws SearchIteratorException, OXException {
+    private final void fillCachedResultSet() throws AbstractOXException {
         try {
             while (non_cached_iterator.hasNext()) {
                 list.add(non_cached_iterator.next());
@@ -215,7 +218,7 @@ public class CachedCalendarIterator implements SearchIterator<CalendarDataObject
         }
     }
 
-    private final CalendarDataObject getPreFilledResult() throws SearchIteratorException, OXException {
+    private final CalendarDataObject getPreFilledResult() throws AbstractOXException {
         Connection readcon = null;
         CalendarDataObject cdao;
         try {
@@ -228,27 +231,27 @@ public class CachedCalendarIterator implements SearchIterator<CalendarDataObject
 			            throw new OXException(ex);
 			        }
 			    }
-			
+
 			    int mn = MAX_PRE_FETCH;
 			    if (mn+pre_fetch > list.size()) {
 			        mn = list.size()%MAX_PRE_FETCH;
 			    }
 			    final int arr[] = new int[mn];
-			
+
 			    for (int a = 0; a < mn; a++) {
 			        CalendarDataObject temp = list.get(pre_fetch++);
 			        arr[a] = temp.getObjectID();
 			    }
-			
+
 			    final String sqlin = StringCollection.getSqlInString(arr);
 			    if  (cdao.fillUserParticipants() || cdao.fillFolderID()) {
 			        try {
-			            new CalendarMySQL().getUserParticipantsSQLIn(list, readcon, c.getContextId(), uid, sqlin);
+			            new CalendarMySQL().getUserParticipantsSQLIn(visibleFolders, list, readcon, c.getContextId(), uid, sqlin);
 			        } catch (final SQLException ex) {
 			            throw new OXCalendarException(OXCalendarException.Code.UNEXPECTED_EXCEPTION, ex, I(202));
 			        }
 			    }
-			
+
 			    if (cdao.fillParticipants()) {
 			        try {
 			            new CalendarMySQL().getParticipantsSQLIn(list, readcon, cdao.getContextID(), sqlin);
@@ -279,7 +282,7 @@ public class CachedCalendarIterator implements SearchIterator<CalendarDataObject
             		}
             	}
             	if (!found) {
-            		throw new OXPermissionException(new OXCalendarException(OXCalendarException.Code.LOAD_PERMISSION_EXCEPTION_5));
+            		throw new OXPermissionException(new OXCalendarException(OXCalendarException.Code.LOAD_PERMISSION_EXCEPTION_5, I(cdao.getObjectID())));
             	}
             }
 
