@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -68,6 +68,7 @@ import com.openexchange.api2.OXException;
 import com.openexchange.calendar.api.CalendarCollection;
 import com.openexchange.group.Group;
 import com.openexchange.group.GroupStorage;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.Types;
 import com.openexchange.groupware.calendar.CalendarAdministrationService;
 import com.openexchange.groupware.calendar.CalendarDataObject;
@@ -84,7 +85,6 @@ import com.openexchange.groupware.ldap.LdapException;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.session.Session;
 import com.openexchange.tools.iterator.SearchIterator;
-import com.openexchange.tools.iterator.SearchIteratorException;
 import com.openexchange.tools.oxfolder.OXFolderIteratorSQL;
 
 /**
@@ -98,17 +98,17 @@ public class CalendarAdministration implements CalendarAdministrationService {
 
     private StringBuilder u1;
 
-    private static final Log LOG = LogFactory.getLog(CalendarAdministration.class);
-    
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(CalendarAdministration.class));
+
     private Set<Integer> handledObjects = new HashSet<Integer>();
-    
+
     /**
      * Initializes a new {@link CalendarAdministration}
      */
     public CalendarAdministration() {
         super();
     }
-    
+
     /* (non-Javadoc)
      * @see com.openexchange.calendar.CalendarAdministrationService#deletePerformed(com.openexchange.groupware.delete.DeleteEvent, java.sql.Connection, java.sql.Connection)
      */
@@ -194,7 +194,7 @@ public class CalendarAdministration implements CalendarAdministrationService {
                 final int folder_id = tuple[1];
                 addUpdateMasterObjectBatch(stmt, session.getUserId(), ctx.getContextId(), object_id);
                 eventHandling(object_id, folder_id, ctx, session, CalendarOperation.UPDATE, con);
-                                
+
             }
             stmt.executeBatch();
 
@@ -272,7 +272,7 @@ public class CalendarAdministration implements CalendarAdministrationService {
             }
         } catch (final OXException e) {
             throw new DowngradeFailedException(e);
-        } catch (final SearchIteratorException e) {
+        } catch (final AbstractOXException e) {
             throw new DowngradeFailedException(e);
         } catch (final SQLException e) {
             LOG.error(e);
@@ -285,7 +285,7 @@ public class CalendarAdministration implements CalendarAdministrationService {
             collection.closeResultSet(rs);
         }
     }
-    
+
     private final void deleteUser(final DeleteEvent deleteEvent, final Connection readcon, final Connection writecon) throws DeleteFailedException, SQLException {
         try {
             //  Delete all appointments where the user is the only participant (and where the app is private) !! NO MOVE TO del_* !!
@@ -297,31 +297,31 @@ public class CalendarAdministration implements CalendarAdministrationService {
             throw new DeleteFailedException(ex);
         }
     }
-    
-    
+
+
     private final void deleteGroup(final DeleteEvent deleteEvent, final Connection readcon, final Connection writecon) throws DeleteFailedException, SQLException {
         deleteObjects(deleteEvent, readcon, writecon, CalendarSql.VIEW_TABLE_NAME, Participant.GROUP);
     }
-    
+
     private final void deleteResource(final DeleteEvent deleteEvent, final Connection readcon, final Connection writecon) throws DeleteFailedException, SQLException {
         deleteObjects(deleteEvent, readcon, writecon, CalendarSql.VIEW_TABLE_NAME, Participant.RESOURCE);
     }
-    
+
     private final void deleteResourceGroup(final DeleteEvent deleteEvent, final Connection readcon, final Connection writecon) throws DeleteFailedException, SQLException {
         deleteObjects(deleteEvent, readcon, writecon, CalendarSql.VIEW_TABLE_NAME, Participant.RESOURCEGROUP);
     }
-    
+
     private final Set<Integer> resolveMembersOfGroups(final int objectId, final DeleteEvent deleteEvent, final int type, final Connection readcon) throws SQLException, LdapException {
         PreparedStatement rightsStatement = null;
         ResultSet rightsResultSet = null;
         Set<Integer> usersInRightsTable = new HashSet<Integer>();
-        
+
         try {
             StringBuilder sb = new StringBuilder();
             sb.append("SELECT id, type FROM ");
             sb.append(CalendarSql.VIEW_TABLE_NAME);
             sb.append(" WHERE cid = ? AND object_id = ? AND type in (?, ?)");
-            
+
             rightsStatement = readcon.prepareStatement(sb.toString());
             rightsStatement.setInt(1, deleteEvent.getContext().getContextId());
             rightsStatement.setInt(2, objectId);
@@ -332,7 +332,7 @@ public class CalendarAdministration implements CalendarAdministrationService {
                 rightsStatement.setInt(3, Participant.RESOURCEGROUP);
                 rightsStatement.setInt(4, Participant.RESOURCE);
             }
-            
+
             rightsResultSet = rightsStatement.executeQuery();
             while (rightsResultSet.next()) {
                 if (rightsResultSet.getInt(2) == Participant.USER) {
@@ -355,25 +355,25 @@ public class CalendarAdministration implements CalendarAdministrationService {
                 rightsStatement.close();
             }
         }
-        
+
         return usersInRightsTable;
     }
-    
+
     private final Set<Integer> getUsers(final int objectId, final Context ctx, final Connection readcon) throws SQLException {
         PreparedStatement membersStatement = null;
         ResultSet membersResultSet = null;
         Set<Integer> usersInMembersTable = new HashSet<Integer>();
-        
+
         try {
             StringBuilder sb = new StringBuilder();
             sb.append("SELECT member_uid FROM ");
             sb.append(CalendarSql.PARTICIPANT_TABLE_NAME);
             sb.append(" WHERE cid = ? AND object_id = ?");
-            
+
             membersStatement = readcon.prepareStatement(sb.toString());
             membersStatement.setInt(1, ctx.getContextId());
             membersStatement.setInt(2, objectId);
-            
+
             membersResultSet = membersStatement.executeQuery();
             while (membersResultSet.next()) {
                 usersInMembersTable.add(I(membersResultSet.getInt(1)));
@@ -386,26 +386,26 @@ public class CalendarAdministration implements CalendarAdministrationService {
                 membersStatement.close();
             }
         }
-        
+
         return usersInMembersTable;
     }
-    
+
     private final void resolveDeletedGroupAndAddMembers(final int objectId, final DeleteEvent deleteEvent, final int type, final Connection readcon, final Connection writecon) throws SQLException, LdapException {
         if ( !(type == Participant.GROUP || type == Participant.RESOURCEGROUP)) {
             return;
         }
-        
+
         if (handledObjects.contains(I(objectId))) {
             return;
         }
-        
+
         PreparedStatement insertStatement = null;
         Set<Integer> usersToAdd = new HashSet<Integer>();
-        
+
         try {
             usersToAdd.addAll(getUsers(objectId, deleteEvent.getContext(), readcon));
             usersToAdd.removeAll(resolveMembersOfGroups(objectId, deleteEvent, type, readcon));
-            
+
             StringBuilder sb = new StringBuilder();
             sb.append("INSERT INTO ");
             sb.append(CalendarSql.VIEW_TABLE_NAME);
@@ -414,7 +414,7 @@ public class CalendarAdministration implements CalendarAdministrationService {
             sb.append("(?, ?, ?, ?)");
 
             insertStatement = writecon.prepareStatement(sb.toString());
-            
+
             for (int id : usersToAdd) {
                 insertStatement.setInt(1, objectId);
                 insertStatement.setInt(2, deleteEvent.getContext().getContextId());
@@ -432,10 +432,10 @@ public class CalendarAdministration implements CalendarAdministrationService {
                 insertStatement.close();
             }
         }
-        
+
         handledObjects.add(I(objectId));
     }
-    
+
     private final void deleteObjects(final DeleteEvent deleteEvent, final Connection readcon, final Connection writecon, final String table, final int type) throws DeleteFailedException, SQLException {
         PreparedStatement pst = null;
         ResultSet rs = null;
@@ -556,7 +556,7 @@ public class CalendarAdministration implements CalendarAdministrationService {
             }
         }
     }
-   
+
     private static final String SQL_DEL_REMINDER = "DELETE FROM reminder WHERE cid = ? AND module = ? AND userid = ?";
 
     private void deleteUserFromAppointments(final DeleteEvent deleteEvent, final Connection readcon, final Connection writecon) throws SQLException, OXException {
@@ -566,6 +566,8 @@ public class CalendarAdministration implements CalendarAdministrationService {
         PreparedStatement pst4 = null;
         PreparedStatement pst5 = null;
         PreparedStatement pst6 = null;
+        PreparedStatement pst7 = null;
+        PreparedStatement pst8 = null;
         CalendarCollection collection = new CalendarCollection();
         try {
         	/*
@@ -579,7 +581,7 @@ public class CalendarAdministration implements CalendarAdministrationService {
         	pst2.executeUpdate();
         	pst2.close();
         	pst2 = null;
-        	
+
             removeAppointmentsWithOnlyTheUserAsParticipant(deleteEvent.getSession(), deleteEvent.getContext(), deleteEvent.getId(), writecon);
 
             final StringBuilder sb2 = new StringBuilder(128);
@@ -604,7 +606,7 @@ public class CalendarAdministration implements CalendarAdministrationService {
             }
             update.executeBatch();
             update.close();
-            
+
             final StringBuilder replace = new StringBuilder(128);
             replace.append("UPDATE ");
             replace.append(CalendarSql.DATES_TABLE_NAME);
@@ -625,7 +627,7 @@ public class CalendarAdministration implements CalendarAdministrationService {
             pst3 = writecon.prepareStatement(replace.toString());
             pst3.addBatch();
             pst3.executeBatch();
-            
+
             final StringBuilder replace_modified_by = new StringBuilder(128);
             replace_modified_by.append("UPDATE ");
             replace_modified_by.append(CalendarSql.DATES_TABLE_NAME);
@@ -646,7 +648,7 @@ public class CalendarAdministration implements CalendarAdministrationService {
             pst4 = writecon.prepareStatement(replace_modified_by.toString());
             pst4.addBatch();
             pst4.executeBatch();
-            
+
             final StringBuilder delete_participant_members = new StringBuilder(128);
             delete_participant_members.append("DELETE FROM prg_dates_members WHERE cid = ");
             delete_participant_members.append(deleteEvent.getContext().getContextId());
@@ -655,7 +657,7 @@ public class CalendarAdministration implements CalendarAdministrationService {
             pst5 = writecon.prepareStatement(delete_participant_members.toString());
             pst5.addBatch();
             pst5.executeBatch();
-            
+
             final StringBuilder delete_participant_rights = new StringBuilder(128);
             delete_participant_rights.append("delete from prg_date_rights WHERE cid = ");
             delete_participant_rights.append(deleteEvent.getContext().getContextId());
@@ -667,6 +669,49 @@ public class CalendarAdministration implements CalendarAdministrationService {
             pst6.addBatch();
             pst6.executeBatch();
             
+            StringBuilder replaceOrganizerId = new StringBuilder();
+            replaceOrganizerId.append("UPDATE ");
+            replaceOrganizerId.append(CalendarSql.DATES_TABLE_NAME);
+            replaceOrganizerId.append(" pd SET ");
+            replaceOrganizerId.append(collection.getFieldName(Appointment.ORGANIZER_ID));
+            replaceOrganizerId.append(" = ");
+            replaceOrganizerId.append("NULL ");
+            replaceOrganizerId.append(", ");
+            replaceOrganizerId.append(collection.getFieldName(Appointment.LAST_MODIFIED));
+            replaceOrganizerId.append(" = ");
+            replaceOrganizerId.append(System.currentTimeMillis());
+            replaceOrganizerId.append(" WHERE cid = ");
+            replaceOrganizerId.append(deleteEvent.getContext().getContextId());
+            replaceOrganizerId.append(" AND ");
+            replaceOrganizerId.append(collection.getFieldName(Appointment.ORGANIZER_ID));
+            replaceOrganizerId.append(" = ");
+            replaceOrganizerId.append(deleteEvent.getId());
+            pst7 = writecon.prepareStatement(replaceOrganizerId.toString());
+            pst7.addBatch();
+            pst7.executeBatch();
+            
+            StringBuilder replacePrincipalId = new StringBuilder();
+            replacePrincipalId.append("UPDATE ");
+            replacePrincipalId.append(CalendarSql.DATES_TABLE_NAME);
+            replacePrincipalId.append(" pd SET ");
+            replacePrincipalId.append(collection.getFieldName(Appointment.PRINCIPAL_ID));
+            replacePrincipalId.append(" = ");
+            replacePrincipalId.append("NULL ");
+            replacePrincipalId.append(", ");
+            replacePrincipalId.append(collection.getFieldName(Appointment.LAST_MODIFIED));
+            replacePrincipalId.append(" = ");
+            replacePrincipalId.append(System.currentTimeMillis());
+            replacePrincipalId.append(" WHERE cid = ");
+            replacePrincipalId.append(deleteEvent.getContext().getContextId());
+            replacePrincipalId.append(" AND ");
+            replacePrincipalId.append(collection.getFieldName(Appointment.PRINCIPAL_ID));
+            replacePrincipalId.append(" = ");
+            replacePrincipalId.append(deleteEvent.getId());
+            pst8 = writecon.prepareStatement(replacePrincipalId.toString());
+            pst8.addBatch();
+            pst8.executeBatch();
+            
+
         } finally {
             if (rs2 != null) {
                 collection.closeResultSet(rs2);
@@ -686,9 +731,15 @@ public class CalendarAdministration implements CalendarAdministrationService {
             if (pst6 != null) {
                 collection.closePreparedStatement(pst6);
             }
+            if (pst7 != null) {
+                collection.closePreparedStatement(pst7);
+            }
+            if (pst8 != null) {
+                collection.closePreparedStatement(pst8);
+            }
         }
     }
-    
+
     private final void addUpdateMasterObjectBatch(final PreparedStatement update, final int mailadmin, final int cid, final int oid) throws SQLException {
         update.setInt(1, mailadmin);
         update.setLong(2, System.currentTimeMillis());
@@ -696,14 +747,14 @@ public class CalendarAdministration implements CalendarAdministrationService {
         update.setInt(4, oid);
         update.addBatch();
     }
-    
+
     private final PreparedStatement getUpdatePreparedStatement(final Connection writecon) throws SQLException {
         if (u1 == null) {
             initializeUpdateString();
         }
         return writecon.prepareStatement(u1.toString());
     }
-    
+
     /* (non-Javadoc)
      * @see com.openexchange.calendar.CalendarAdministrationService#initializeUpdateString()
      */
@@ -719,7 +770,7 @@ public class CalendarAdministration implements CalendarAdministrationService {
         u1.append(collection.getFieldName(Appointment.OBJECT_ID));
         u1.append(" = ?");
     }
-    
+
     private final void eventHandling(final int object_id, final int in_folder, final Context context, final Session so, final int type, final Connection readcon) throws SQLException, OXException {
         final CalendarOperation co = new CalendarOperation();
         final CalendarSqlImp cimp = new CalendarMySQL();
@@ -766,5 +817,5 @@ public class CalendarAdministration implements CalendarAdministrationService {
             }
         };
     }
-    
+
 }
