@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,13 +58,12 @@ import java.util.Arrays;
 import java.util.Comparator;
 import java.util.Date;
 import java.util.List;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-
 import com.openexchange.api2.OXException;
 import com.openexchange.calendar.api.CalendarCollection;
 import com.openexchange.database.DBPoolingException;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.calendar.CalendarConfig;
 import com.openexchange.groupware.calendar.CalendarDataObject;
 import com.openexchange.groupware.calendar.Constants;
@@ -79,26 +78,25 @@ import com.openexchange.groupware.userconfiguration.UserConfigurationStorage;
 import com.openexchange.server.impl.DBPool;
 import com.openexchange.session.Session;
 import com.openexchange.tools.iterator.SearchIterator;
-import com.openexchange.tools.iterator.SearchIteratorException;
 
 /**
  * ConflictHandler
  * @author <a href="mailto:martin.kauss@open-xchange.org">Martin Kauss</a>
  */
 public class ConflictHandler {
-    
+
     private final CalendarDataObject cdao;
     private final Session so;
     private boolean create = true;
     private int current_results;
-    
+
     public static final int MAX_CONFLICT_RESULTS = 999;
-    
+
     public static final CalendarDataObject NO_CONFLICTS[] = new CalendarDataObject[0];
-    
-    private static final Log LOG = LogFactory.getLog(ConflictHandler.class);
-    private CalendarDataObject edao;
-    private CalendarCollection recColl;
+
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ConflictHandler.class));
+    private final CalendarDataObject edao;
+    private final CalendarCollection recColl;
 
     public ConflictHandler(final CalendarDataObject cdao,final CalendarDataObject edao, final Session so, final boolean create) {
         this.cdao = cdao;
@@ -107,7 +105,7 @@ public class ConflictHandler {
         this.create = create;
         this.recColl = new CalendarCollection();
     }
-    
+
     public CalendarDataObject[] getConflicts() throws OXException {
         final Context ctx = Tools.getContext(so);
         if (cdao.getShownAs() == CalendarDataObject.FREE || !UserConfigurationStorage.getInstance().getUserConfigurationSafe(so.getUserId(), ctx).hasConflictHandling()) {
@@ -117,8 +115,10 @@ public class ConflictHandler {
                 LOG.debug("Ignoring conflict checks because we detected an update and no start/end time, recurrence type or participants and shown as are changed!");
             }
             return NO_CONFLICTS;
-        } else if (cdao.containsEndDate() && recColl.checkMillisInThePast(cdao.getEndDate().getTime())) {
-            return NO_CONFLICTS; // Past apps should never conflict
+        } else if (cdao.isSingle() && cdao.containsEndDate() && recColl.checkMillisInThePast(cdao.getEndDate().getTime())) {
+            return NO_CONFLICTS; // Past single apps should never conflict
+        } else if (cdao.isSequence() && recColl.checkMillisInThePast(recColl.getMaxUntilDate(cdao).getTime())) {
+            return NO_CONFLICTS; // Past series apps should never conflict
         } else if (!create && !cdao.containsShownAs() && (cdao.getShownAs() == CalendarDataObject.FREE)) {
             //if (cdao.getShownAs() == CalendarDataObject.FREE) {
             return NO_CONFLICTS; // According to bug #5267
@@ -145,7 +145,7 @@ public class ConflictHandler {
         return NO_CONFLICTS;
     }
 
-    private CalendarDataObject[] prepareResolving(boolean request_participants) throws OXException {
+    private CalendarDataObject[] prepareResolving(final boolean request_participants) throws OXException {
         /*
          * Using original method {@link #resolveResourceConflicts(Date, Date)}
          * for non series appointments.
@@ -158,42 +158,38 @@ public class ConflictHandler {
         }
         if (request_participants) {
             return resolveParticipantsRecurring();
-        } else {
-            /*
-             * Using optimized method {@link #resolveResourceConflicts(Date, Date, RecurringResults)}
-             * for series appointments.
-             */
-    		final RecurringResultsInterface results = recColl.calculateRecurring(cdao, 0, 0, 0);
-    		final Date resultStart = new Date(results.getRecurringResult(0).getStart());
-    		final Date resultEnd = new Date(results.getRecurringResult(results.size() - 1).getEnd());
-    	    final CalendarDataObject[] resultConflicts = resolveResourceConflicts(resultStart, resultEnd, results);
-    	    // Results must be sorted afterwards because already existing series
-    	    // appointments are returned in time reverse order by FreeBusyResults.
-    	    // Because of 999 maximum number of conflicts the returned array may
-    	    // contain a lot of appointments far in the future.
-    	    Arrays.sort(resultConflicts, new Comparator<CalendarDataObject>() {
-                public int compare(final CalendarDataObject cdao1, final CalendarDataObject cdao2) {
-                    return cdao1.getStartDate().compareTo(cdao2.getStartDate());
-                }
-    	    });
-            return resultConflicts;
         }
+        // Using optimized method {@link #resolveResourceConflicts(Date, Date, RecurringResults)} for series appointments.
+        final RecurringResultsInterface results = recColl.calculateRecurring(cdao, 0, 0, 0);
+        final Date resultStart = new Date(results.getRecurringResult(0).getStart());
+        final Date resultEnd = new Date(results.getRecurringResult(results.size() - 1).getEnd());
+        final CalendarDataObject[] resultConflicts = resolveResourceConflicts(resultStart, resultEnd, results);
+        // Results must be sorted afterwards because already existing series
+        // appointments are returned in time reverse order by FreeBusyResults.
+        // Because of 999 maximum number of conflicts the returned array may
+        // contain a lot of appointments far in the future.
+        Arrays.sort(resultConflicts, new Comparator<CalendarDataObject>() {
+            public int compare(final CalendarDataObject cdao1, final CalendarDataObject cdao2) {
+                return cdao1.getStartDate().compareTo(cdao2.getStartDate());
+            }
+        });
+        return resultConflicts;
 	}
-    
+
     private CalendarDataObject[] resolveParticipantsRecurring() throws OXException {
-        long limit = CalendarConfig.getSeriesConflictLimit() ? System.currentTimeMillis() + Constants.MILLI_YEAR : 0;
-        RecurringResultsInterface rresults = recColl.calculateRecurring(cdao, 0, limit , 0);
+        final long limit = CalendarConfig.getSeriesConflictLimit() ? System.currentTimeMillis() + Constants.MILLI_YEAR : 0;
+        final RecurringResultsInterface rresults = recColl.calculateRecurring(cdao, 0, limit , 0);
         for (int i = 0; i < rresults.size(); i++) {
-            RecurringResultInterface recurringResult = rresults.getRecurringResult(i);
-            CalendarDataObject[] conflicts = resolveParticipantConflicts(new Date(recurringResult.getStart()), new Date(recurringResult.getEnd()));
+            final RecurringResultInterface recurringResult = rresults.getRecurringResult(i);
+            final CalendarDataObject[] conflicts = resolveParticipantConflicts(new Date(recurringResult.getStart()), new Date(recurringResult.getEnd()));
             if (conflicts.length > 0) {
                 return conflicts;
             }
         }
-        
+
         return NO_CONFLICTS;
     }
-    
+
     private CalendarDataObject[] resolveParticipantConflicts(final Date start, final Date end) throws OXException {
         final String sql_in = recColl.getSQLInStringForParticipants(getConflictUsers());
         if (sql_in == null) {
@@ -204,12 +200,12 @@ public class ConflictHandler {
         SearchIterator<CalendarDataObject> si = null;
         ResultSet rs = null;
         PreparedStatement prep = null;
-        PreparedStatement private_folder_information = null;
+        SearchIterator<List<Integer>> private_folder_information = null;
         boolean close_connection = true;
         final Context ctx = Tools.getContext(so);
         final User user = Tools.getUser(so, ctx);
         try {
-            readcon = DBPool.pickup(ctx);            
+            readcon = DBPool.pickup(ctx);
             final long whole_day_start = recColl.getUserTimeUTCDate(start, user.getTimeZone());
             long whole_day_end = recColl.getUserTimeUTCDate(end, user.getTimeZone());
             if (whole_day_end <= whole_day_start) {
@@ -255,32 +251,38 @@ public class ConflictHandler {
                 return ret;
             }
             return NO_CONFLICTS;
-        } catch (final SearchIteratorException sie) {
+        } catch (final DBPoolingException dbpe) {
+            throw new OXException(dbpe);
+        } catch (final AbstractOXException sie) {
             throw new OXCalendarException(OXCalendarException.Code.UNEXPECTED_EXCEPTION, sie, Integer.valueOf(12));
         } catch (final SQLException sqle) {
             throw new OXCalendarException(OXCalendarException.Code.CALENDAR_SQL_ERROR, sqle);
-        } catch (final DBPoolingException dbpe) {
-            throw new OXException(dbpe);
         } finally {
             if (close_connection) {
                 if (null != si) {
                     try {
                         si.close();
-                    } catch (final SearchIteratorException sie) {
+                    } catch (final AbstractOXException sie) {
                         LOG.error("Error closing SearchIterator" ,sie);
                     }
                 }
                 recColl.closeResultSet(rs);
                 recColl.closePreparedStatement(prep);
-                recColl.closePreparedStatement(private_folder_information);
+                if (null != private_folder_information) {
+                    try {
+                        private_folder_information.close();
+                    } catch (final AbstractOXException e) {
+                        // Ignore
+                    }
+                }
             }
             if (close_connection && readcon != null) {
                 DBPool.push(ctx, readcon);
             }
         }
     }
-    
-    boolean shouldConflict(CalendarDataObject cdao, CalendarDataObject conflictDao) {
+
+    boolean shouldConflict(final CalendarDataObject cdao, final CalendarDataObject conflictDao) {
         if (create) {
             return true;
         }
@@ -297,8 +299,8 @@ public class ConflictHandler {
     }
 
     private List<UserParticipant> getConflictUsers() {
-        List<UserParticipant> relevantUsers = new ArrayList<UserParticipant>();
-        for (UserParticipant user : cdao.getUsers()) {
+        final List<UserParticipant> relevantUsers = new ArrayList<UserParticipant>();
+        for (final UserParticipant user : cdao.getUsers()) {
             switch (user.getConfirm()) {
             case CalendarObject.ACCEPT:
                 relevantUsers.add(user);
@@ -314,10 +316,10 @@ public class ConflictHandler {
                 break;
             }
         }
-        
+
         return relevantUsers;
     }
-    
+
     private CalendarDataObject[] resolveResourceConflicts(final Date start, final Date end) throws OXException {
         final String sql_in = recColl.getSQLInStringForResources(cdao.getParticipants());
         if (sql_in == null) {
@@ -328,7 +330,7 @@ public class ConflictHandler {
         SearchIterator<?> si = null;
         ResultSet rs = null;
         PreparedStatement prep  = null;
-        PreparedStatement private_folder_information = null;
+        SearchIterator<List<Integer>> private_folder_information = null;
         boolean close_connection = true;
         final Context ctx = Tools.getContext(so);
         final User user = Tools.getUser(so, ctx);
@@ -352,7 +354,7 @@ public class ConflictHandler {
                     if (li == null) {
                         li = new ArrayList<CalendarDataObject>();
                     }
-                    
+
                     if (!(!create && cdao.getObjectID() == conflict_dao.getObjectID())) { // Same id should never conflict if we are running an update
                         if (!cdao.containsRecurrencePosition()) {
                             if (!recColl.checkMillisInThePast(conflict_dao.getEndDate().getTime())) {
@@ -389,22 +391,28 @@ public class ConflictHandler {
                 return ret;
             }
             return NO_CONFLICTS;
-        } catch (final SearchIteratorException sie) {
+        } catch (final DBPoolingException dbpe) {
+            throw new OXException(dbpe);
+        } catch (final AbstractOXException sie) {
             throw new OXCalendarException(OXCalendarException.Code.UNEXPECTED_EXCEPTION, sie, Integer.valueOf(13));
         } catch (final SQLException sqle) {
             throw new OXCalendarException(OXCalendarException.Code.CALENDAR_SQL_ERROR, sqle);
-        } catch (final DBPoolingException dbpe) {
-            throw new OXException(dbpe);
         } finally {
             if (close_connection && si != null) {
                 try {
                     si.close();
-                } catch (final SearchIteratorException sie) {
+                } catch (final AbstractOXException sie) {
                     LOG.error("Error closing SearchIterator" ,sie);
                 }
                 recColl.closeResultSet(rs);
                 recColl.closePreparedStatement(prep);
-                recColl.closePreparedStatement(private_folder_information);
+                if (null != private_folder_information) {
+                    try {
+                        private_folder_information.close();
+                    } catch (final AbstractOXException e) {
+                        // Ignore
+                    }
+                }
             }
             if (close_connection && readcon != null) {
                 DBPool.push(ctx, readcon);
@@ -439,7 +447,7 @@ public class ConflictHandler {
         SearchIterator<CalendarDataObject> si = null;
         ResultSet rs = null;
         PreparedStatement prep  = null;
-        PreparedStatement private_folder_information = null;
+        SearchIterator<List<Integer>> private_folder_information = null;
         boolean close_connection = true;
         final Context ctx = Tools.getContext(so);
         final User user = Tools.getUser(so, ctx);
@@ -465,7 +473,7 @@ public class ConflictHandler {
                 if (recColl.checkMillisInThePast(conflict_dao.getEndDate().getTime())) {
                     continue;
                 }
-                if (!create && cdao.getObjectID() == conflict_dao.getObjectID()) { // Same id should never conflict if we are running an update
+                if (!create && !shouldConflict(cdao, conflict_dao)) { // Same id should never conflict if we are running an update
                     continue;
                 }
                 for (int i = 0; i < results.size() && current_results < MAX_CONFLICT_RESULTS; i++) {
@@ -490,29 +498,35 @@ public class ConflictHandler {
                 return ret;
             }
             return NO_CONFLICTS;
-        } catch (final SearchIteratorException sie) {
+        } catch (final DBPoolingException dbpe) {
+            throw new OXException(dbpe);
+        } catch (final AbstractOXException sie) {
             throw new OXCalendarException(OXCalendarException.Code.UNEXPECTED_EXCEPTION, sie, Integer.valueOf(13));
         } catch (final SQLException sqle) {
             throw new OXCalendarException(OXCalendarException.Code.CALENDAR_SQL_ERROR, sqle);
-        } catch (final DBPoolingException dbpe) {
-            throw new OXException(dbpe);
         } finally {
             if (close_connection && si != null) {
                 try {
                     si.close();
-                } catch (final SearchIteratorException sie) {
+                } catch (final AbstractOXException sie) {
                     LOG.error("Error closing SearchIterator" ,sie);
                 }
                 recColl.closeResultSet(rs);
                 recColl.closePreparedStatement(prep);
-                recColl.closePreparedStatement(private_folder_information);
+                if (null != private_folder_information) {
+                    try {
+                        private_folder_information.close();
+                    } catch (final AbstractOXException e) {
+                        // Ignore
+                    }
+                }
             }
             if (close_connection && readcon != null) {
                 DBPool.push(ctx, readcon);
             }
         }
     }
-    
+
     private final boolean containsResources() {
         return cdao.containsResources();
     }
