@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -84,7 +84,7 @@ import com.openexchange.tools.iterator.SearchIteratorException;
  * @author <a href="mailto:martin.kauss@open-xchange.org">Martin Kauss</a>
  */
 public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
-    
+
     public final static int MAX_SHOW_USER_PARTICIPANTS = 5;
 
     private final List<AbstractOXException> warnings;
@@ -109,28 +109,28 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
     private final Participant conflict_objects[];
     private final long range_start;
     private final long range_end;
-    
+
     private int last_up_oid;
     private UserParticipant last_up[];
     private int last_p_oid;
     private Participant last_p[];
-    
+
     private List<CalendarDataObject> al = new ArrayList<CalendarDataObject>(16);
     private int counter;
-    
+
     private PrivateFolderInformationObject[] private_folder_array;
-    private final PreparedStatement private_folder_information;
+    private final SearchIterator<List<Integer>> private_folder_information;
 
     private final CalendarSqlImp calendarsqlimp;
 
     private final CalendarCollection recColl;
-    
+
     private int readFolderId;
 
     private String categories;
-    
-    private static final Log LOG = LogFactory.getLog(FreeBusyResults.class);
-    
+
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(FreeBusyResults.class));
+
     /*public FreeBusyResults(final ResultSet rs, final PreparedStatement prep, final Context c, final Connection con, final long range_start, final long range_end) throws OXException {
     	this.warnings =  new ArrayList<AbstractOXException>(2);
     	this.rs = rs;
@@ -142,12 +142,12 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
         rsNext();
         preFill();
     }*/
-    
-    public FreeBusyResults(final ResultSet rs, final PreparedStatement prep, final Context c, final int uid, final int groups[], final UserConfiguration uc, final Connection con, final boolean show_details, final Participant conflict_objects[], final PreparedStatement private_folder_information, final CalendarSqlImp calendarsqlimp) throws OXException {
+
+    public FreeBusyResults(final ResultSet rs, final PreparedStatement prep, final Context c, final int uid, final int groups[], final UserConfiguration uc, final Connection con, final boolean show_details, final Participant conflict_objects[], final SearchIterator<List<Integer>> private_folder_information, final CalendarSqlImp calendarsqlimp) throws OXException {
     	this(rs, prep, c, uid, groups, uc, con, show_details, conflict_objects, private_folder_information, calendarsqlimp, 0, 0);
     }
 
-    public FreeBusyResults(final ResultSet rs, final PreparedStatement prep, final Context c, final int uid, final int groups[], final UserConfiguration uc, final Connection con, final boolean show_details, final Participant conflict_objects[], final PreparedStatement private_folder_information, final CalendarSqlImp calendarsqlimp, final long range_start, final long range_end) throws OXException {
+    public FreeBusyResults(final ResultSet rs, final PreparedStatement prep, final Context c, final int uid, final int groups[], final UserConfiguration uc, final Connection con, final boolean show_details, final Participant conflict_objects[], final SearchIterator<List<Integer>> private_folder_information, final CalendarSqlImp calendarsqlimp, final long range_start, final long range_end) throws OXException {
     	this.warnings =  new ArrayList<AbstractOXException>(2);
     	this.rs = rs;
         this.prep = prep;
@@ -168,7 +168,7 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
         rsNext();
         preFill();
     }
-    
+
     private final void preFill() throws OXException {
         try {
             while (myhasNext()) {
@@ -186,11 +186,11 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
             myclose();
         }
     }
-    
+
     public final CalendarDataObject next() {
         return al.get(counter++);
     }
-    
+
     public final CalendarDataObject mynext() throws SearchIteratorException, OXException {
         CalendarDataObject cdao = null;
         if (seq >= 0 && rrs != null) {
@@ -267,11 +267,11 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
         rsNext();
         return cdao;
     }
-    
+
     public int size() {
-        throw new UnsupportedOperationException("Mehtod size() not implemented");
+        return -1;
     }
-    
+
     public boolean hasSize() {
         return false;
     }
@@ -287,7 +287,7 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
 	public boolean hasWarnings() {
 		return !warnings.isEmpty();
 	}
-    
+
     private final CalendarDataObject recurringDAO(final RecurringResultInterface rr) throws OXException {
         if (rr != null) {
             final CalendarDataObject cdao = new CalendarDataObject();
@@ -310,7 +310,7 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
 
     private void fillDetails(final CalendarDataObject cdao) throws OXException {
         if (show_details) {
-            if (checkPermissions()) {                
+            if (checkPermissions()) {
                 cdao.setTitle(title);
                 cdao.setParentFolderID(readFolderId);
                 cdao.setLabel(colorLabel);
@@ -320,21 +320,21 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
             cdao.setParticipants(ret.getList());
         }
     }
-    
+
     public boolean hasNext() {
         if (!al.isEmpty() && counter < al.size()) {
             return true;
         }
         return false;
     }
-    
+
     public final boolean myhasNext() {
         if (seq >= 0) {
             return true;
         }
         return has_next;
     }
-    
+
     private void rsNext() {
         if (rs != null) {
             try {
@@ -345,29 +345,36 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
             }
         }
     }
-    
+
     public void close() {
         al = null;
         title = null;
         rrs = null;
     }
-    
+
     public final void myclose() {
         recColl.closeResultSet(rs);
         recColl.closePreparedStatement(prep);
-        recColl.closePreparedStatement(private_folder_information);
+        if (null != private_folder_information) {
+            try {
+                private_folder_information.close();
+            } catch (final AbstractOXException e) {
+                // Ignore
+            }
+        }
         if (con != null) {
             DBPool.push(c, con);
         }
     }
-    
+
     private final boolean checkPermissions() {
+        boolean isVisible = isVisible();
         if ((pflag == 0 && isVisible()) || (pflag == 1 && owner == uid)) {
             return true;
         }
         return false;
     }
-    
+
     private final boolean isVisible() {
         if (cfo == null) {
             return false;
@@ -400,16 +407,16 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
                             readFolderId = p;
                             return true;
                         }
-                    } 
+                    }
                 }
             }
         }
         return false;
     }
-    
+
     private final void preFillPermissionArray(final int groups[], final UserConfiguration uc) throws OXException {
         try {
-            cfo = recColl.getAllVisibleAndReadableFolderObject(uid, groups, c, uc);
+            cfo = recColl.getAllVisibleAndReadableFolderObject(uid, groups, c, uc, con);
         } catch (final OXException ex) {
             throw new OXException(ex);
         } catch (final DBPoolingException ex) {
@@ -420,7 +427,7 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
             throw new OXCalendarException(OXCalendarException.Code.CALENDAR_SQL_ERROR, ex);
         }
     }
-    
+
     private final Participants resolveConflictingUserParticipants() throws OXException {
         final Participants p = new Participants();
         int counter = 0;
@@ -488,7 +495,7 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
         }
         return p;
     }
-    
+
     private final void preFillPrivateFolderInformation() {
 
         final List<PrivateFolderInformationObject> list = new ArrayList<PrivateFolderInformationObject>(16);
@@ -498,24 +505,21 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
         int uid = 0;
         PreparedStatement shared_folder_info = null;
         try {
-            
 
-            ResultSet result = private_folder_information.executeQuery();
-            while (result.next()) {
-                object_id = result.getInt(1);
-                pfid = result.getInt(2);
-                uid = result.getInt(3);
-                if (!result.wasNull()) {
-                    final PrivateFolderInformationObject pfio = new PrivateFolderInformationObject(object_id, pfid, uid);
-                    list.add(pfio);
-                }
+            for (final SearchIterator<List<Integer>> iter = private_folder_information; iter.hasNext();) {
+                final List<Integer> vals = iter.next();
+                object_id = vals.get(0).intValue();
+                pfid = vals.get(1).intValue();
+                uid = vals.get(2).intValue();
+                final PrivateFolderInformationObject pfio = new PrivateFolderInformationObject(object_id, pfid, uid);
+                list.add(pfio);
             }
-            result.close();
+
             // Add shared folders and check if there are such shared folders
             if (! cfo.getSharedFolderList().isEmpty()) {
                 shared_folder_info = calendarsqlimp.getSharedAppointmentFolderQuery(c, cfo, con);
-    
-                result = shared_folder_info.executeQuery();
+
+                final ResultSet result = shared_folder_info.executeQuery();
                 while (result.next()) {
                     object_id = result.getInt(1);
                     pfid = result.getInt(2);
@@ -529,6 +533,8 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
             }
         } catch(final SQLException sqle) {
             LOG.error(sqle.getMessage(), sqle);
+        } catch (final AbstractOXException e) {
+            LOG.error(e.getMessage(), e);
         } finally {
             if(shared_folder_info != null) {
                 try {
@@ -540,5 +546,5 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
         }
         private_folder_array = list.toArray(new PrivateFolderInformationObject[list.size()]);
     }
-    
+
 }
