@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -75,7 +75,7 @@ public class RecurrenceChecker {
         if (!cdao.containsInterval())
             throw new OXCalendarException(OXCalendarException.Code.INCOMPLETE_REC_INFOS_INTERVAL);
 
-        if (cdao.containsUntil() && cdao.containsOccurrence() && !(cdao.getUntil() == null && cdao.getOccurrence() == 0))
+        if (cdao.containsUntil() && cdao.containsOccurrence() && cdao.getUntil() != null && cdao.getOccurrence() != 0)
             throw new OXCalendarException(OXCalendarException.Code.REDUNDANT_UNTIL_OCCURRENCES);
 
         if (cdao.getRecurrenceType() == CalendarObject.DAILY)
@@ -116,7 +116,7 @@ public class RecurrenceChecker {
 
         if (!cdao.containsDays())
             throw new OXCalendarException(OXCalendarException.Code.INCOMPLETE_REC_INFOS_WEEKDAY);
-        
+
         if (cdao.getDays() < 1 || cdao.getDays() > 127)
             throw new OXCalendarException(OXCalendarException.Code.RECURRING_MISSING_OR_WRONG_VALUE_DAYS, cdao.getDays());
     }
@@ -145,7 +145,7 @@ public class RecurrenceChecker {
     private static void checkMonthly2(CalendarObject cdao) throws OXCalendarException {
         if (!cdao.containsDays())
             throw new OXCalendarException(OXCalendarException.Code.RECURRING_MISSING_OR_WRONG_VALUE_DAYS);
-        
+
         if (cdao.getDays() < 1 || cdao.getDays() > 127)
             throw new OXCalendarException(OXCalendarException.Code.RECURRING_MISSING_OR_WRONG_VALUE_DAYS, cdao.getDays());
 
@@ -177,7 +177,7 @@ public class RecurrenceChecker {
     private static void checkYearly2(CalendarObject cdao) throws OXCalendarException {
         if (!cdao.containsDays())
             throw new OXCalendarException(OXCalendarException.Code.RECURRING_MISSING_OR_WRONG_VALUE_DAYS);
-        
+
         if (cdao.getDays() < 1 || cdao.getDays() > 127)
             throw new OXCalendarException(OXCalendarException.Code.RECURRING_MISSING_OR_WRONG_VALUE_DAYS, cdao.getDays());
 
@@ -188,13 +188,13 @@ public class RecurrenceChecker {
 
     /**
      * Checks, if the given CalendarDataObject contains any recurrence information.
-     * 
+     *
      * @param cdao
      * @param exceptions Recurrence fields, which will not be checked
      * @return
      */
     public static boolean containsRecurrenceInformation(CalendarObject cdao, int... exceptions) {
-        Set<Integer> reucrrenceFields = new HashSet<Integer>() {
+        Set<Integer> recurrenceFields = new HashSet<Integer>() {
 
             {
                 add(CalendarObject.INTERVAL);
@@ -207,17 +207,17 @@ public class RecurrenceChecker {
         };
 
         boolean skipType = false;
-        
+
         for (int exception : exceptions) {
-            reucrrenceFields.remove(exception);
+            recurrenceFields.remove(exception);
             if (exception == CalendarObject.RECURRENCE_TYPE)
                 skipType = true;
         }
 
         if (!skipType && cdao.contains(CalendarObject.RECURRENCE_TYPE) && (Integer)cdao.get(CalendarObject.RECURRENCE_TYPE) != CalendarObject.NO_RECURRENCE)
             return true;
-        
-        for (int recurrenceField : reucrrenceFields) {
+
+        for (int recurrenceField : recurrenceFields) {
             if (cdao.contains(recurrenceField))
                 return true;
         }
