@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,25 +49,53 @@
 
 package com.openexchange.calendar.api;
 
+import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.HashSet;
+import java.util.List;
+import java.util.Set;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import com.openexchange.api2.AppointmentSQLInterface;
 import com.openexchange.calendar.CalendarSql;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.calendar.AppointmentSqlFactoryService;
 import com.openexchange.session.Session;
 
 /**
  * Factory class for getting new Instances of the type AppointmentSQLInterface.
- * 
+ *
  * @author <a href="mailto:martin.herfurth@open-xchange.org">Martin Herfurth</a>
  */
 public class AppointmentSqlFactory implements AppointmentSqlFactoryService {
 
-    /**
-     * Facrory method for creating a new Instance.
-     * 
-     * @param session
-     * @return
-     */
-    public AppointmentSQLInterface createAppointmentSql(Session session) {
-        return new CalendarSql(session);
+	private static final Log LOG = LogFactory.getLog(AppointmentSqlFactory.class);
+	
+    private List<CalendarFeature> features = new ArrayList<CalendarFeature>();
+    
+    public AppointmentSQLInterface createAppointmentSqlOmittingFeatures(Session session, String...omitFeatures) {
+        Set<String> skip = new HashSet<String>(Arrays.asList(omitFeatures));
+        AppointmentSQLInterface calendarSql = new TransactionallyCachingCalendar(new CalendarSql(session)); 
+
+        for (CalendarFeature feature : features) {
+            if (!skip.contains(feature.getId())) {
+                try {
+					calendarSql = feature.wrap(calendarSql, session);
+				} catch (AbstractOXException e) {
+					LOG.error(e.getMessage(), e);
+				}
+            }
+        }
+        
+        return calendarSql;
     }
+    
+    public void addCalendarFeature(CalendarFeature feature) {
+        features.add(feature);
+    }
+    
+    public AppointmentSQLInterface createAppointmentSql(Session session) {
+        return createAppointmentSqlOmittingFeatures(session);
+    }
+    
 }
