@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -60,9 +60,13 @@ import java.sql.Types;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
+import java.util.Set;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import com.openexchange.groupware.calendar.OXCalendarException;
 import com.openexchange.groupware.calendar.OXCalendarException.Code;
 import com.openexchange.groupware.container.ExternalUserParticipant;
@@ -80,7 +84,7 @@ public class RdbParticipantStorage extends ParticipantStorage {
     }
 
     @Override
-    public void insertParticipants(Context ctx, Connection con, int appointmentId, ExternalUserParticipant[] participants) throws OXCalendarException {
+    public void insertParticipants(final Context ctx, final Connection con, final int appointmentId, final ExternalUserParticipant[] participants) throws OXCalendarException {
         if (null == participants || 0 == participants.length) {
             return;
         }
@@ -90,23 +94,36 @@ public class RdbParticipantStorage extends ParticipantStorage {
             int pos = 1;
             stmt.setInt(pos++, ctx.getContextId());
             stmt.setInt(pos++, appointmentId);
-            for (ExternalUserParticipant participant : participants) {
+            final Set<String> addresses = new HashSet<String>(participants.length);
+            for (final ExternalUserParticipant participant : participants) {
                 pos = 3;
-                stmt.setString(pos++, participant.getEmailAddress());
-                String displayName = participant.getDisplayName();
-                if (null == displayName) {
-                    stmt.setNull(pos++, Types.VARCHAR);
+                final String emailAddress = participant.getEmailAddress();
+                if (addresses.add(emailAddress)) {
+                    stmt.setString(pos++, emailAddress);
+                    final String displayName = participant.getDisplayName();
+                    if (null == displayName) {
+                        stmt.setNull(pos++, Types.VARCHAR);
+                    } else {
+                        stmt.setString(pos++, displayName);
+                    }
+                    stmt.setInt(pos++, participant.getConfirm());
+                    final String message = participant.getMessage();
+                    if (null == message) {
+                        stmt.setNull(pos++, Types.VARCHAR);
+                    } else {
+                        stmt.setString(pos++, message);
+                    }
+                    stmt.addBatch();
                 } else {
-                    stmt.setString(pos++, displayName);
+                    /*
+                     * Duplicate address
+                     */
+                    final Log logger = com.openexchange.log.Log.valueOf(LogFactory.getLog(RdbParticipantStorage.class));
+                    if (logger.isWarnEnabled()) {
+                        final OXCalendarException e = new OXCalendarException(Code.DUPLICATE_EXTERNAL_PARTICIPANT, emailAddress);
+                        logger.warn(e.getMessage());
+                    }
                 }
-                stmt.setInt(pos++, participant.getConfirm());
-                String message = participant.getMessage();
-                if (null == message) {
-                    stmt.setNull(pos++, Types.VARCHAR);
-                } else {
-                    stmt.setString(pos++, message);
-                }
-                stmt.addBatch();
             }
             stmt.executeBatch();
             // TODO data truncation should be catched if some too long messages should be stored.
@@ -120,66 +137,66 @@ public class RdbParticipantStorage extends ParticipantStorage {
     }
 
     @Override
-    public Map<Integer, ExternalUserParticipant[]> selectExternal(Context ctx, Connection con, int[] appointmentIds) throws OXCalendarException {
+    public Map<Integer, ExternalUserParticipant[]> selectExternal(final Context ctx, final Connection con, final int[] appointmentIds) throws OXCalendarException {
         PreparedStatement stmt = null;
         ResultSet rs = null;
         final Map<Integer, List<ExternalUserParticipant>> retval = new HashMap<Integer, List<ExternalUserParticipant>>(appointmentIds.length, 1);
-        for (int appointmentId : appointmentIds) {
+        for (final int appointmentId : appointmentIds) {
             retval.put(I(appointmentId), new ArrayList<ExternalUserParticipant>());
         }
         try {
             stmt = con.prepareStatement(getIN(SQL.SELECT_EXTERNAL, appointmentIds.length));
             int pos = 1;
             stmt.setInt(pos++, ctx.getContextId());
-            for (int appointmentId : appointmentIds) {
+            for (final int appointmentId : appointmentIds) {
                 stmt.setInt(pos++, appointmentId);
             }
             rs = stmt.executeQuery();
             while (rs.next()) {
                 pos = 1;
                 final int appointmentId = rs.getInt(pos++);
-                ExternalUserParticipant participant = new ExternalUserParticipant(rs.getString(pos++));
+                final ExternalUserParticipant participant = new ExternalUserParticipant(rs.getString(pos++));
                 participant.setDisplayName(rs.getString(pos++));
                 participant.setConfirm(rs.getInt(pos++));
                 participant.setMessage(rs.getString(pos++));
-                List<ExternalUserParticipant> participants = retval.get(I(appointmentId));
+                final List<ExternalUserParticipant> participants = retval.get(I(appointmentId));
                 participants.add(participant);
             }
-        } catch (SQLException e) {
+        } catch (final SQLException e) {
             throw new OXCalendarException(Code.SQL_ERROR, e);
         } finally {
             closeSQLStuff(rs, stmt);
         }
         final Map<Integer, ExternalUserParticipant[]> retval2 = new HashMap<Integer, ExternalUserParticipant[]>();
-        for (Entry<Integer, List<ExternalUserParticipant>> entry : retval.entrySet()) {
-            List<ExternalUserParticipant> participants = entry.getValue();
+        for (final Entry<Integer, List<ExternalUserParticipant>> entry : retval.entrySet()) {
+            final List<ExternalUserParticipant> participants = entry.getValue();
             retval2.put(entry.getKey(), participants.toArray(new ExternalUserParticipant[participants.size()]));
         }
         return Collections.unmodifiableMap(retval2);
     }
 
     @Override
-    public void deleteParticipants(Context ctx, Connection con, int appointmentId, ExternalUserParticipant[] participants) throws OXCalendarException {
+    public void deleteParticipants(final Context ctx, final Connection con, final int appointmentId, final ExternalUserParticipant[] participants) throws OXCalendarException {
         PreparedStatement stmt = null;
         try {
             stmt = con.prepareStatement(SQL.DELETE_EXTERNAL);
             int pos = 1;
             stmt.setInt(pos++, ctx.getContextId());
             stmt.setInt(pos++, appointmentId);
-            for (ExternalUserParticipant participant : participants) {
+            for (final ExternalUserParticipant participant : participants) {
                 stmt.setString(pos, participant.getEmailAddress());
                 stmt.addBatch();
             }
-            int[] rowss = stmt.executeBatch();
+            final int[] rowss = stmt.executeBatch();
             if (rowss.length != participants.length) {
                 throw new OXCalendarException(Code.WRONG_ROW_COUNT, I(participants.length), I(rowss.length));
             }
-            for (int rows : rowss) {
+            for (final int rows : rowss) {
                 if (1 != rows) {
                     throw new OXCalendarException(Code.WRONG_ROW_COUNT, I(1), I(rows));
                 }
             }
-        } catch (SQLException e) {
+        } catch (final SQLException e) {
             throw new OXCalendarException(Code.SQL_ERROR, e);
         } finally {
             closeSQLStuff(stmt);
